@@ -1,4 +1,4 @@
-"""
+'''
 # aws-iot-lambda module
 
 <!--BEGIN STABILITY BANNER-->---
@@ -102,7 +102,7 @@ Out of the box implementation of the Construct without any override will set the
 
 
 © Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -134,7 +134,7 @@ class IotToLambda(
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
-        """
+        '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param iot_topic_rule_props: User provided CfnTopicRuleProps to override the defaults. Default: - None
@@ -144,7 +144,7 @@ class IotToLambda(
         :access: public
         :since: 0.8.0
         :summary: Constructs a new instance of the IotToLambda class.
-        """
+        '''
         props = IotToLambdaProps(
             iot_topic_rule_props=iot_topic_rule_props,
             existing_lambda_obj=existing_lambda_obj,
@@ -153,15 +153,15 @@ class IotToLambda(
 
         jsii.create(IotToLambda, self, [scope, id, props])
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="iotTopicRule")
     def iot_topic_rule(self) -> aws_cdk.aws_iot.CfnTopicRule:
-        return jsii.get(self, "iotTopicRule")
+        return typing.cast(aws_cdk.aws_iot.CfnTopicRule, jsii.get(self, "iotTopicRule"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
-        return jsii.get(self, "lambdaFunction")
+        return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
 
 @jsii.data_type(
@@ -181,13 +181,13 @@ class IotToLambdaProps:
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
-        """
+        '''
         :param iot_topic_rule_props: User provided CfnTopicRuleProps to override the defaults. Default: - None
         :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
         :summary: The properties for the IotToLambda class.
-        """
+        '''
         if isinstance(iot_topic_rule_props, dict):
             iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
         if isinstance(lambda_function_props, dict):
@@ -202,33 +202,33 @@ class IotToLambdaProps:
 
     @builtins.property
     def iot_topic_rule_props(self) -> aws_cdk.aws_iot.CfnTopicRuleProps:
-        """User provided CfnTopicRuleProps to override the defaults.
+        '''User provided CfnTopicRuleProps to override the defaults.
 
         :default: - None
-        """
+        '''
         result = self._values.get("iot_topic_rule_props")
         assert result is not None, "Required property 'iot_topic_rule_props' is missing"
-        return result
+        return typing.cast(aws_cdk.aws_iot.CfnTopicRuleProps, result)
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
+        '''Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
         :default: - None
-        """
+        '''
         result = self._values.get("existing_lambda_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
 
     @builtins.property
     def lambda_function_props(
         self,
     ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
-        """User provided props to override the default props for the Lambda function.
+        '''User provided props to override the default props for the Lambda function.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("lambda_function_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
